@@ -37,13 +37,6 @@
 #define DEBUG 1
 */
 
-static unsigned short normal_i2c[] = { SENSORS_I2C_END };
-static unsigned short normal_i2c_range[] = { SENSORS_I2C_END };
-static unsigned int normal_isa[] = { SENSORS_ISA_END };
-static unsigned int normal_isa_range[] = { SENSORS_ISA_END };
-
-SENSORS_INSMOD_1(bmcsensors);
-
 struct bmcsensors_data {
 	struct semaphore lock;
 	int sysctl_id;
@@ -91,15 +84,11 @@ static struct i2c_driver bmcsensors_driver = {
 };
 
 static struct bmcsensors_data bmc_data;
-struct i2c_client bmc_client = {
-	"BMC Sensors",
-	1,                  /* fake should be 0 */
-	0,
-	0,
-	NULL,   /* adapter */
-	&bmcsensors_driver,
-	& bmc_data,
-	0
+static struct i2c_client bmc_client = {
+	.name		= "BMC Sensors",
+	.id		= 1,                  /* fake should be 0 */
+	.driver		= &bmcsensors_driver,
+	.data		= &bmc_data,
 };
 
 static int bmcsensors_initialized;
@@ -152,7 +141,8 @@ static ctl_table *bmcsensors_dir_table;
 static char *bmcsensors_proc_name_pool;
 
 #define IPMI_SDR_SIZE 67
-static int ipmi_sdr_partial_size = IPMI_SDR_SIZE;
+#define IPMI_CHUNK_SIZE 16
+static int ipmi_sdr_partial_size = IPMI_CHUNK_SIZE;
 static struct ipmi_msg tx_message;	/* send message */
 static unsigned char tx_msg_data[IPMI_MAX_MSG_LENGTH + 50];
 static unsigned char rx_msg_data[IPMI_MAX_MSG_LENGTH + 50]; /* sloppy */
@@ -217,8 +207,10 @@ static void ipmi_sprintf(u8 * to, u8 * from, u8 type, u8 length)
 		case 2: 	/* packed ascii */ /* if not a mult. of 3 this will run over */     
 			for(i = 0; i < length; i += 3) {
 				*to++ = *from & 0x3f;
-				*to++ = *from++ >> 6 | ((*from & 0xf)  << 2);
-				*to++ = *from++ >> 4 | ((*from & 0x3)  << 4);
+				*to++ = *from >> 6 | ((*(from+1) & 0xf)  << 2);
+				from++;
+				*to++ = *from >> 4 | ((*(from+1) & 0x3)  << 4);
+				from++;
 				*to++ = (*from++ >> 2) & 0x3f;
 			}
 			*to = 0;
@@ -297,7 +289,7 @@ static void bmcsensors_select_thresholds(struct sdrdata * sd)
 	}
 
 	/* swap lim1/lim2 if m < 0 or function is 1/x (but not both!) */
-	if(m < 0 && sd->linear != 7 || m >= 0 && sd->linear == 7) {
+	if((sd->m < 0 && sd->linear != 7) || (sd->m >= 0 && sd->linear == 7)) {
 		tmp = sd->lim1;
 		sd->lim1 = sd->lim2;
 		sd->lim2 = tmp;
@@ -463,6 +455,7 @@ static int bmcsensors_rcv_sdr_msg(struct ipmi_msg *msg, int state)
 	int id_length;
 	int i;
 	int rstate = STATE_SDR;
+	int ipmi_ver = 0;
 	unsigned char * data;
 	u8 id[SDR_MAX_UNPACKED_ID_LENGTH];
 
@@ -504,7 +497,7 @@ static int bmcsensors_rcv_sdr_msg(struct ipmi_msg *msg, int state)
 	}
 
 	nextrecord = (data[2] << 8) | data[1];
-	/* printk(KERN_INFO "bmcsensors.o: nextrecord %d \n", nextrecord); */
+	/* printk(KERN_INFO "bmcsensors.o: nextrecord %d\n", nextrecord); */
 
 
 	type = data[6];
@@ -516,7 +509,7 @@ static int bmcsensors_rcv_sdr_msg(struct ipmi_msg *msg, int state)
 		entity = data[11];
 		init = data[13];
 */
-		stype = data[15];
+		stype = data[(ipmi_ver == 0x90?16:15)];
 		if(stype <= STYPE_MAX) {	/* known sensor type */
 			if(bmcs_count[stype] >= bmcs_max[stype]) {
 				if(bmcs_max[stype] > 0)
@@ -534,11 +527,11 @@ static int bmcsensors_rcv_sdr_msg(struct ipmi_msg *msg, int state)
 				       "bmcsensors.o: Limit of %d exceeded for total sensors\n",
 				       MAX_SDR_ENTRIES);
 				nextrecord = 0xffff;
-			} else if(data[16] != 0x01) {
+			} else if(data[(ipmi_ver == 0x90?17:16)] != 0x01) {
 				if(type == 1)
 					ipmi_sprintf(id, &data[51], data[50] >> 6, data[50] & 0x1f);
 				else
-					ipmi_sprintf(id, &data[35], data[34] >> 6, data[34] & 0x1f);
+					ipmi_sprintf(id, &data[(ipmi_ver == 0x90?30:35)], data[(ipmi_ver == 0x90?29:34)] >> 6, data[(ipmi_ver == 0x90?29:34)] & 0x1f);
 				printk(KERN_INFO
 				       "bmcsensors.o: skipping non-threshold sensor \"%s\"\n",
 				       id);
@@ -546,23 +539,23 @@ static int bmcsensors_rcv_sdr_msg(struct ipmi_msg *msg, int state)
 				/* add entry to sdrd table */
 				sdrd[sdrd_count].stype = stype;
 				sdrd[sdrd_count].number = data[10];
-				sdrd[sdrd_count].capab = data[14];
-				sdrd[sdrd_count].thresh_mask = (((u16) data[22]) << 8) | data[21];
+				sdrd[sdrd_count].capab = data[(ipmi_ver == 0x90?15:14)];
+				sdrd[sdrd_count].thresh_mask = (((u16) data[(ipmi_ver == 0x90?21:22)]) << 8) | data[21];
 				if(type == 1) {
-					sdrd[sdrd_count].format = data[24] >> 6;
-					sdrd[sdrd_count].linear = data[26] & 0x7f;
-					sdrd[sdrd_count].m = data[27];
-					sdrd[sdrd_count].m |= ((u16) (data[28] & 0xc0)) << 2;
+					sdrd[sdrd_count].format = data[(ipmi_ver == 0x90?22:24)] >> 6;
+					sdrd[sdrd_count].linear = data[(ipmi_ver == 0x90?25:26)] & 0x7f;
+					sdrd[sdrd_count].m = data[(ipmi_ver == 0x90?26:27)];
+					sdrd[sdrd_count].m |= ((u16) (data[(ipmi_ver == 0x90?27:28)] & 0xc0)) << 2;
 					if(sdrd[sdrd_count].m & 0x0200)
 						sdrd[sdrd_count].m |= 0xfc00;	/* sign extend */
-					sdrd[sdrd_count].b = data[29];
-					sdrd[sdrd_count].b |= ((u16) (data[30] & 0xc0)) << 2;
+					sdrd[sdrd_count].b = data[(ipmi_ver == 0x90?28:29)];
+					sdrd[sdrd_count].b |= ((u16) (data[(ipmi_ver == 0x90?29:30)] & 0xc0)) << 2;
 					if(sdrd[sdrd_count].b & 0x0200)
 						sdrd[sdrd_count].b |= 0xfc00;	/* sign extend */
-					sdrd[sdrd_count].k = data[32];
-					sdrd[sdrd_count].nominal = data[34];
+					sdrd[sdrd_count].k = data[(ipmi_ver == 0x90?31:32)];
+					sdrd[sdrd_count].nominal = data[(ipmi_ver == 0x90?33:34)];
 					for(i = 0; i < SDR_LIMITS; i++)		/* assume readable */
-						sdrd[sdrd_count].limits[i] = data[39 + i];
+						sdrd[sdrd_count].limits[i] = data[(ipmi_ver == 0x90?40:39) + i];
 					sdrd[sdrd_count].string_type = data[50] >> 6;
 					id_length = data[50] & 0x1f;
 					memcpy(sdrd[sdrd_count].id, &data[51], id_length);
@@ -571,12 +564,16 @@ static int bmcsensors_rcv_sdr_msg(struct ipmi_msg *msg, int state)
 					sdrd[sdrd_count].m = 1;
 					sdrd[sdrd_count].b = 0;
 					sdrd[sdrd_count].k = 0;
-					sdrd[sdrd_count].string_type = data[34] >> 6;
+					sdrd[sdrd_count].string_type = data[(ipmi_ver == 0x90?29:34)] >> 6;
 					id_length = data[34] & 0x1f;
 					if(id_length > 0)
-						memcpy(sdrd[sdrd_count].id, &data[35], id_length);
+						memcpy(sdrd[sdrd_count].id, &data[(ipmi_ver == 0x90?30:35)], id_length);
 					sdrd[sdrd_count].id_length = id_length;
 					/* limits?? */
+					if(ipmi_ver == 0x90){
+						memcpy(sdrd[sdrd_count].id, &data[30], id_length);
+						sdrd[sdrd_count].id_length = id_length;
+					}
 				}
 				bmcs_count[stype]++;
 				sdrd_count++;
@@ -611,7 +608,12 @@ static int bmcsensors_rcv_sdr_msg(struct ipmi_msg *msg, int state)
 	if (nextrecord>=6224) {
 	  nextrecord = 0xffff; /*YJ stop sensor scan on poweredge 1750 */
 	}
-			
+	if (ipmi_ver != 0x90) {
+ 		if (nextrecord>=6224) {
+ 			nextrecord = 0xffff; /*YJ stop sensor scan on poweredge 1750 */
+ 		}
+  	}
+		
 	if(nextrecord == 0xFFFF) {
 		if(sdrd_count == 0) {
 			printk(KERN_INFO "bmcsensors.o: No recognized sensors found.\n");
@@ -821,7 +823,7 @@ static int bmcsensors_detect(struct i2c_adapter *adapter, int address,
 	receive_counter = 0;
 	rx_msg_data_offset = 0;
 	errorcount = 0;
-	ipmi_sdr_partial_size = IPMI_SDR_SIZE;
+	ipmi_sdr_partial_size = IPMI_CHUNK_SIZE;
 	for(i = 0; i <= STYPE_MAX; i++)
 		bmcs_count[i] = 0;
 
