@@ -43,9 +43,8 @@ SENSORS_INSMOD_1(ds1621);
 
 /* Config register used for detection         */
 /*  7    6    5    4    3    2    1    0      */
-/* |Done|THF |TLF |NVB | 1  | 0  |POL |1SHOT| */
-#define DS1621_REG_CONFIG_MASK 0x0C
-#define DS1621_REG_CONFIG_VAL 0x08
+/* |Done|THF |TLF |NVB | X  | X  |POL |1SHOT| */
+#define DS1621_REG_CONFIG_NVB 0x10
 #define DS1621_REG_CONFIG_POLARITY 0x02
 #define DS1621_REG_CONFIG_1SHOT 0x01
 #define DS1621_REG_CONFIG_DONE 0x80
@@ -125,7 +124,7 @@ static struct i2c_driver ds1621_driver = {
 };
 
 /* -- SENSORS SYSCTL START -- */
-#define DS1621_SYSCTL_TEMP 1200	/* Degrees Celcius * 10 */
+#define DS1621_SYSCTL_TEMP 1200	/* Degrees Celsius * 10 */
 #define DS1621_SYSCTL_ALARMS 2001	/* bitvector */
 #define DS1621_ALARM_TEMP_HIGH 0x40
 #define DS1621_ALARM_TEMP_LOW 0x20
@@ -154,18 +153,16 @@ static ctl_table ds1621_dir_table_template[] = {
 	{0}
 };
 
-static int ds1621_id = 0;
-
 static int ds1621_attach_adapter(struct i2c_adapter *adapter)
 {
 	return i2c_detect(adapter, &addr_data, ds1621_detect);
 }
 
 /* This function is called by i2c_detect */
-int ds1621_detect(struct i2c_adapter *adapter, int address,
-		unsigned short flags, int kind)
+static int ds1621_detect(struct i2c_adapter *adapter, int address,
+			 unsigned short flags, int kind)
 {
-	int i, conf;
+	int i, conf, temp;
 	struct i2c_client *new_client;
 	struct ds1621_data *data;
 	int err = 0;
@@ -203,10 +200,25 @@ int ds1621_detect(struct i2c_adapter *adapter, int address,
 
 	/* Now, we do the remaining detection. It is lousy. */
 	if (kind < 0) {
+		/* The NVB bit should be low if no EEPROM write has been
+		   requested during the latest 10ms, which is highly
+		   improbable in our case. */
 		conf = i2c_smbus_read_byte_data(new_client,
 						DS1621_REG_CONF);
-		if ((conf & DS1621_REG_CONFIG_MASK)
-		    != DS1621_REG_CONFIG_VAL)
+		if (conf & DS1621_REG_CONFIG_NVB)
+			goto ERROR1;
+		/* The 7 lowest bits of a temperature should always be 0. */
+		temp = ds1621_read_value(new_client, 
+					 DS1621_REG_TEMP);
+		if (temp & 0x007f)
+			goto ERROR1;
+		temp = ds1621_read_value(new_client, 
+					 DS1621_REG_TEMP_HYST);
+		if (temp & 0x007f)
+			goto ERROR1;
+		temp = ds1621_read_value(new_client, 
+					 DS1621_REG_TEMP_OVER);
+		if (temp & 0x007f)
 			goto ERROR1;
 	}
 
@@ -227,8 +239,6 @@ int ds1621_detect(struct i2c_adapter *adapter, int address,
 
 	/* Fill in remaining client fields and put it into the global list */
 	strcpy(new_client->name, client_name);
-
-	new_client->id = ds1621_id++;
 	data->valid = 0;
 	init_MUTEX(&data->update_lock);
 
@@ -311,7 +321,7 @@ static void ds1621_init_client(struct i2c_client *client)
 	int reg;
 
 	reg = ds1621_read_value(client, DS1621_REG_CONF);
-	/* start the continous conversion */
+	/* start the continuous conversion */
 	if(reg & 0x01)
 		ds1621_write_value(client, DS1621_REG_CONF, reg & 0xfe);
 }
@@ -352,7 +362,7 @@ static void ds1621_update_client(struct i2c_client *client)
 				ds1621_write_value(client, DS1621_COM_START, 0);
 		}
 
-		/* reset alarms if neccessary */
+		/* reset alarms if necessary */
 		new_conf = data->conf;
 		if (data->temp < data->temp_over)
 			new_conf &= ~DS1621_ALARM_TEMP_HIGH;
@@ -430,7 +440,7 @@ void ds1621_enable(struct i2c_client *client, int operation, int ctl_name,
 		   int *nrels_mag, long *results)
 {
 	/* If you really screw up your chip (like I did) this is */
-	/* sometimes needed to (re)start the continous conversion */
+	/* sometimes needed to (re)start the continuous conversion */
 	/* there is no data to read so this might hang your SMBus! */
 
 	struct ds1621_data *data = client->data;
