@@ -24,6 +24,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include "util.h"
 #include "i2cbusses.h"
 #include "i2c-dev.h"
 #include "version.h"
@@ -55,7 +56,7 @@ int main(int argc, char *argv[])
 	int i, j, res, i2cbus, address, size, file;
 	int bank = 0, bankreg = 0x4E, old_bank = 0;
 	char filename[20];
-	long funcs;
+	unsigned long funcs;
 	int block[256];
 	int pec = 0, even = 0;
 	int flags = 0;
@@ -254,8 +255,6 @@ int main(int argc, char *argv[])
 	}
 
 	if (!yes) {
-		char s[2];
-
 		fprintf(stderr, "WARNING! This program can confuse your I2C "
 		        "bus, cause data loss and worse!\n");
 
@@ -281,8 +280,7 @@ int main(int argc, char *argv[])
 
 		fprintf(stderr, "Continue? [Y/n] ");
 		fflush(stderr);
-		if (!fgets(s, 2, stdin)
-		 || (s[0] != '\n' && s[0] != 'y' && s[0] != 'Y')) {
+		if (!user_ack(1)) {
 			fprintf(stderr, "Aborting on user request.\n");
 			exit(0);
 		}
